CA25_Cl02.html
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Panoramic views |
clickAndWait | link=Añadir panoramic view |
clickAndWait | _continue |
verifyTextPresent | Por favor, corrija los siguientes errores. |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | exact:Nombre: |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | exact:Url: |
clickAndWait | link=Terminar sesión |